==> piwigo-11.5.0.zip: piwigo/language/pl_PL/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalacja';
$lang['Basic configuration'] = 'Podstawowa konfiguracja';
$lang['Default gallery language'] = 'Domyślny język galerii';
$lang['Database configuration'] = 'Konfiguracja bazy danych';
$lang['Admin configuration'] = 'Konfiguracja administratora';
$lang['Start Install'] = 'Rozpoczęcie instalacji';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'To będzie wyświetlone dla odwiedzających i jest konieczne do celów administracyjnych ';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Połączenie do serwera powiodło się, ale nie było możliwe połączenie do bazy danych';
$lang['Can\'t connect to server'] = 'Nie można połączyć się do serwera';
$lang['Host'] = 'MySQL host';
$lang['User'] = 'Użytkownik';
$lang['user login given by your host provider'] = 'login użytkownika otrzymany od dostawy';
$lang['user password given by your host provider'] = 'hasło użytkownika otrzymane od dostawcy';
$lang['Database name'] = 'Nazwa bazy danych';
$lang['also given by your host provider'] = 'także otrzymana od dostawcy';
$lang['Database table prefix'] = 'Prefix tabel bazy danych';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'tabele w bazie danych będą miały taki prefix (ułatwia to zarządzanie tabelami)';
$lang['enter a login for webmaster'] = 'wprowadź nazwę użytkownika posiadającego uprawnienia Webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'login nie może zawierać następujących znaków \' lub "';
$lang['please enter your password again'] = 'wprowadź hasło jeszcze raz';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Zachowaj hasło, umożliwia ono dostęp do panelu administracyjnego';
$lang['Password [confirm]'] = 'Hasło [potwierdź]';
$lang['verification'] = 'weryfikacja';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potrzebujesz pomocy ? Zadaj pytanie na <a href="%s">Forum Piwigo</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Z jego pomocą odwiedzający będą mogli się skontaktować z administratorem strony';
$lang['PHP 5 is required'] = 'PHP 5.2 jest wymagane';
$lang['It appears your webhost is currently running PHP %s.'] = 'Twój serwer aktualnie używa PHP w wersji %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo może spróbować przełączyć Twoją konfigurację do PHP 5.2 poprzez modyfikację pliku .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Możesz również zmienić tę konfigurację sam, a następnie uruchomić ponownie Piwigo.';
$lang['Try to configure PHP 5'] = 'Spróbuj skonfigurować PHP 5.2';
$lang['Sorry!'] = 'Niestety!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nie mógł skonfigurować Twojego PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Możesz skontaktować się z działem wsparcia Twojego providera aby dowiedzieć się jak włączyć PHP 5.2';
$lang['Hope to see you back soon.'] = 'Do zobaczenia wkrótce.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulacje, instalacja Piwigo zakończona sukcesem';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatywnym rozwiązaniem jest skopiować tekst z powyższego textbox i wkleić do pliku "local/config/database.inc.php" (Uwaga : database.inc.php musi zawierać to co jest w textbox i nie może zawierać znaków spacji oraz enter)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Nie powiodło się stworzenie pliku konfiguracyjnego local/config/database.inc.php.';
$lang['Download the config file'] = 'Pobierz plik konfiguracyjny';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Możesz pobrać plik konfiguracyjny i wgrać go do katalogu lokalnego/z konfiguracją.';
$lang['Just another Piwigo gallery'] = 'Kolejna galeria Piwigo';
$lang['Welcome to my photo gallery'] = 'Witaj w mojej galerii zdjęć';
$lang['Welcome to your new installation of Piwigo!'] = 'Witamy w Towjej nowej instalacji Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Nie obawiaj się kontaktu na forum w celu skorzystania z pomocy: %s';
$lang['localhost or other, supplied by your host provider'] = 'localhost lub iny, dostarczone przez Twojego dostawcę';

==> piwigo-16.2.0.zip: piwigo/language/pl_PL/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalacja';
$lang['Basic configuration'] = 'Podstawowa konfiguracja';
$lang['Default gallery language'] = 'Domyślny język galerii';
$lang['Database configuration'] = 'Konfiguracja bazy danych';
$lang['Admin configuration'] = 'Konfiguracja administratora';
$lang['Start Install'] = 'Rozpoczęcie instalacji';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'To będzie wyświetlone dla odwiedzających i jest konieczne do celów administracyjnych ';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Połączenie do serwera powiodło się, ale nie było możliwe połączenie do bazy danych';
$lang['Can\'t connect to server'] = 'Nie można połączyć się do serwera';
$lang['Host'] = 'MySQL host';
$lang['User'] = 'Użytkownik';
$lang['user login given by your host provider'] = 'login użytkownika otrzymany od dostawy';
$lang['user password given by your host provider'] = 'hasło użytkownika otrzymane od dostawcy';
$lang['Database name'] = 'Nazwa bazy danych';
$lang['also given by your host provider'] = 'także otrzymana od dostawcy';
$lang['Database table prefix'] = 'Prefix tabel bazy danych';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'tabele w bazie danych będą miały taki prefix (ułatwia to zarządzanie tabelami)';
$lang['enter a login for webmaster'] = 'wprowadź nazwę użytkownika posiadającego uprawnienia Webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'login nie może zawierać następujących znaków \' lub "';
$lang['please enter your password again'] = 'wprowadź hasło jeszcze raz';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Zachowaj hasło, umożliwia ono dostęp do panelu administracyjnego';
$lang['Password [confirm]'] = 'Hasło [potwierdź]';
$lang['verification'] = 'weryfikacja';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potrzebujesz pomocy ? Zadaj pytanie na <a href="%s">Forum Piwigo</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Z jego pomocą odwiedzający będą mogli się skontaktować z administratorem strony';
$lang['PHP 5 is required'] = 'PHP 5.2 jest wymagane';
$lang['It appears your webhost is currently running PHP %s.'] = 'Twój serwer aktualnie używa PHP w wersji %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo może spróbować przełączyć Twoją konfigurację do PHP 5.2 poprzez modyfikację pliku .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Możesz również zmienić tę konfigurację sam, a następnie uruchomić ponownie Piwigo.';
$lang['Try to configure PHP 5'] = 'Spróbuj skonfigurować PHP 5.2';
$lang['Sorry!'] = 'Niestety!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nie mógł skonfigurować Twojego PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Możesz skontaktować się z działem wsparcia Twojego providera aby dowiedzieć się jak włączyć PHP 5.2';
$lang['Hope to see you back soon.'] = 'Do zobaczenia wkrótce.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulacje, instalacja Piwigo zakończona sukcesem';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatywnym rozwiązaniem jest skopiować tekst z powyższego textbox i wkleić do pliku "local/config/database.inc.php" (Uwaga : database.inc.php musi zawierać to co jest w textbox i nie może zawierać znaków spacji oraz enter)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Nie powiodło się stworzenie pliku konfiguracyjnego local/config/database.inc.php.';
$lang['Download the config file'] = 'Pobierz plik konfiguracyjny';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Możesz pobrać plik konfiguracyjny i wgrać go do katalogu lokalnego/z konfiguracją.';
$lang['Just another Piwigo gallery'] = 'Kolejna galeria Piwigo';
$lang['Welcome to my photo gallery'] = 'Witaj w mojej galerii zdjęć';
$lang['Welcome to your new installation of Piwigo!'] = 'Witamy w Towjej nowej instalacji Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Nie obawiaj się kontaktu na forum w celu skorzystania z pomocy: %s';
$lang['localhost or other, supplied by your host provider'] = 'localhost lub iny, dostarczone przez Twojego dostawcę';
$lang['PHP version %s required (you are running on PHP %s)'] = 'Wymagana jest wersja %s PHP (używasz wersji %s)';
